Crate percentum

Crate percentum 

Structs

Fraction
Wrapper type that contains a fractional value
Points
Wrapper type that contains a percentage points value

Enums

Percentage
Percentage type that tracks whether the intenal value represents percentage points or a fractional part.

Traits

Number
A number that can be used as a Percentage value