pub enum Percentage<T> {
Fraction(Fraction<T>),
Points(Points<T>),
}Expand description
Percentage type that tracks whether the intenal value represents percentage points or a fractional part.
Variants
Implementations
Sourceimpl<T> Percentage<T>where
T: Number,
impl<T> Percentage<T>where
T: Number,
Sourcepub const fn from_fraction(fraction: T) -> Self
pub const fn from_fraction(fraction: T) -> Self
Construct a Percentage from a fractional value
Sourcepub const fn from_points(points: T) -> Self
pub const fn from_points(points: T) -> Self
Construct a Percentage from a percentage points value
Sourcepub fn to_fraction(self) -> T
pub fn to_fraction(self) -> T
Obtain the fractional representation of the Percentage
Sourcepub fn to_points(self) -> T
pub fn to_points(self) -> T
Obtain the points representation of the Percentage
Sourcepub fn to_fraction_mut(&mut self) -> &mut T
pub fn to_fraction_mut(&mut self) -> &mut T
Mutate the inner value as a fraction
Sourcepub fn to_points_mut(&mut self) -> &mut T
pub fn to_points_mut(&mut self) -> &mut T
Mutate the inner value as points
Sourcepub fn update_fraction(&mut self, f: impl FnOnce(T) -> T)
pub fn update_fraction(&mut self, f: impl FnOnce(T) -> T)
In-place update the inner value as a fraction
Sourcepub fn update_points(&mut self, f: impl FnOnce(T) -> T)
pub fn update_points(&mut self, f: impl FnOnce(T) -> T)
In-place update the inner value as points
Sourcepub fn apply_to(self, other: T) -> T
pub fn apply_to(self, other: T) -> T
Compute the quantity that represents the percentage of other
Sourcepub fn gain_loss(final_value: T, initial_value: T) -> Option<Self>
pub fn gain_loss(final_value: T, initial_value: T) -> Option<Self>
Compute the percentage gained or lost between the initial and final value.
Sourcepub fn part_of_the_whole(part: T, whole: T) -> Option<Self>
pub fn part_of_the_whole(part: T, whole: T) -> Option<Self>
Compute the percentage of the whole represented by the part